==> moodle-1.5-mysql.tgz: moodle/lang/zh_cn_utf8/chat.php <==
<?PHP // $Id$ 
      // chat.php - created with Moodle 1.5 ALPHA (2005050600)


$string['beep'] = '呼叫';
$string['chatintro'] = '简介文字';
$string['chatname'] = '此聊天室名称';
$string['chatreport'] = '聊天话题';
$string['chattime'] = '下次聊天时间';
$string['configmethod'] = '普通的聊天模式让客户端持续的联系服务器以获取更新。这种方式无需任何配置便可在所有环境下工作，但当很多人一起聊天时会给服务器带来极大负荷。使用聊天服务器程序需要访问Unix的shell，但却可以得到一个快速而稳定的聊天环境。';
$string['configoldping'] = '用户多久(秒)不发言被认为是离开了？这只是一个上限，通常用户的离开是可以马上被检测到的。你可以根据需要设置较低的值，但如果你使用普通的聊天模式，那么<strong>永远不要</strong>让它低于2*chat_refresh_room';
$string['configrefreshroom'] = '聊天室自动刷新时间(秒),如果太短将耗费大量服务器资源';
$string['configrefreshuserlist'] = '用户列表自动刷新时间(秒)';
$string['configserverhost'] = '运行着聊天服务器的计算机的域名';
$string['configserverip'] = '与上面的域名相对应的IP地址';
$string['configservermax'] = '最多允许多少客户端';
$string['configserverport'] = '服务器上聊天程序所使用的端口';
$string['currentchats'] = '当前话题';
$string['currentusers'] = '当前用户';
$string['deletesession'] = '删除该session';
$string['deletesessionsure'] = '确定删除该session吗?';
$string['donotusechattime'] = '不显示聊天时间';
$string['enterchat'] = '点此进入聊天室';
$string['errornousers'] = '没有用户';
$string['explaingeneralconfig'] = '这些设置会<strong>立即</strong>生效';
$string['explainmethoddaemon'] = '这些设置<strong>只有</strong>在您选择了“聊天服务器程序”的聊天模式时才会有效';
$string['explainmethodnormal'] = '这些设置<strong>只有</strong>在您选择了“普通方式”的聊天模式时才会有效';
$string['generalconfig'] = '常规设置';
$string['helpchatting'] = '聊天辅助';
$string['idle'] = '空闲';
$string['messagebeepseveryone'] = '$a 呼叫所有人';
$string['messagebeepsyou'] = '$a 呼叫你';
$string['messageenter'] = '$a 加入该聊天';
$string['messageexit'] = '$a 退出该聊天';
$string['messages'] = '消息';
$string['methoddaemon'] = '聊天服务器程序';
$string['methodnormal'] = '普通方式';
$string['modulename'] = '聊天';
$string['modulenameplural'] = '聊天';
$string['neverdeletemessages'] = '从未删除消息';
$string['nextsession'] = '下一个议定主题';
$string['noguests'] = '此聊天室不对访客(guest)开放';
$string['nomessages'] = '尚无消息';
$string['repeatdaily'] = '每天的此刻';
$string['repeatnone'] = '无回复';
$string['repeattimes'] = '回复主题';
$string['repeatweekly'] = '每周的此刻';
$string['savemessages'] = '保存过去的主题';
$string['seesession'] = '查看主题';
$string['sessions'] = '聊天主题';
$string['strftimemessage'] = '%%H:%%M';
$string['studentseereports'] = '所有人都可查看过去的议题';
$string['viewreport'] = '查看过去的议题';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/zh_cn_utf8/chat.php <==
<?PHP // $Id$ 
      // chat.php - created with Moodle 1.5 ALPHA (2005050600)


$string['beep'] = '呼叫';
$string['chatintro'] = '简介文字';
$string['chatname'] = '此聊天室名称';
$string['chatreport'] = '聊天话题';
$string['chattime'] = '下次聊天时间';
$string['configmethod'] = '普通的聊天模式让客户端持续的联系服务器以获取更新。这种方式无需任何配置便可在所有环境下工作，但当很多人一起聊天时会给服务器带来极大负荷。使用聊天服务器程序需要访问Unix的shell，但却可以得到一个快速而稳定的聊天环境。';
$string['configoldping'] = '用户多久(秒)不发言被认为是离开了？这只是一个上限，通常用户的离开是可以马上被检测到的。您可以根据需要设置较低的值，但如果您使用普通的聊天模式，那么<strong>永远不要</strong>让它低于2*chat_refresh_room';
$string['configrefreshroom'] = '聊天室自动刷新时间(秒),如果太短将耗费大量服务器资源';
$string['configrefreshuserlist'] = '用户列表自动刷新时间(秒)';
$string['configserverhost'] = '运行着聊天服务器的计算机的域名';
$string['configserverip'] = '与上面的域名相对应的IP地址';
$string['configservermax'] = '最多允许多少客户端';
$string['configserverport'] = '服务器上聊天程序所使用的端口';
$string['currentchats'] = '当前话题';
$string['currentusers'] = '当前用户';
$string['deletesession'] = '删除该session';
$string['deletesessionsure'] = '确定删除该session吗?';
$string['donotusechattime'] = '不显示聊天时间';
$string['enterchat'] = '点此进入聊天室';
$string['errornousers'] = '没有用户';
$string['explaingeneralconfig'] = '这些设置会<strong>立即</strong>生效';
$string['explainmethoddaemon'] = '这些设置<strong>只有</strong>在您选择了“聊天服务器程序”的聊天模式时才会有效';
$string['explainmethodnormal'] = '这些设置<strong>只有</strong>在您选择了“普通方式”的聊天模式时才会有效';
$string['generalconfig'] = '常规设置';
$string['helpchatting'] = '聊天辅助';
$string['idle'] = '空闲';
$string['messagebeepseveryone'] = '$a 呼叫所有人';
$string['messagebeepsyou'] = '$a 呼叫您';
$string['messageenter'] = '$a 加入该聊天';
$string['messageexit'] = '$a 退出该聊天';
$string['messages'] = '消息';
$string['methoddaemon'] = '聊天服务器程序';
$string['methodnormal'] = '普通方式';
$string['modulename'] = '聊天';
$string['modulenameplural'] = '聊天';
$string['neverdeletemessages'] = '从未删除消息';
$string['nextsession'] = '下一个议定主题';
$string['noguests'] = '此聊天室不对访客(guest)开放';
$string['nomessages'] = '尚无消息';
$string['repeatdaily'] = '每天的此刻';
$string['repeatnone'] = '无回复';
$string['repeattimes'] = '回复主题';
$string['repeatweekly'] = '每周的此刻';
$string['savemessages'] = '保存过去的主题';
$string['seesession'] = '查看主题';
$string['sessions'] = '聊天主题';
$string['strftimemessage'] = '%%H:%%M';
$string['studentseereports'] = '所有人都可查看过去的议题';
$string['viewreport'] = '查看过去的议题';

?>
